Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func BuildAcceptProfile ¶
func BuildAcceptProfile(profiles []protocol.AcceptProfile) ([]string, error)
BuildAcceptProfile builds the accept profile string array from the AcceptProfile structures
func IsValidDirectKey ¶ added in v2.11.7
IsValidDirectKey checks that provided direct recipient key is valid for usage
func ParseAcceptProfile ¶
func ParseAcceptProfile(profile string) (protocol.AcceptProfile, error)
ParseAcceptProfile parses the accept profile string and returns the AcceptProfile struct
func ResolveRecipientKeyFromDIDDoc ¶ added in v2.11.7
func ResolveRecipientKeyFromDIDDoc(diddoc *verifiable.DIDDocument, filters ...verifiable.VerificationMethodFilterOpt) (jwk.Key, error)
ResolveRecipientKeyFromDIDDoc resolves recipient key from did document by key alg
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.